==> hoteldruid-mod-pt_2.1.3-2.tar.gz: pt/modt_com.php <==
<?php

switch ($messaggio) {

case "Procedere con la prenotazione":	$messaggio = "Progredir com a reserva"; $tr = 1; break;
case "altro":  				$messaggio = "outro"; $tr = 1; break;
case "Indirizzo":  			$messaggio = "Endereço"; $tr = 1; break;
case "Prenota":  			$messaggio = "Reservar"; $tr = 1; break;
case "comportati come se non vi fosse più disponibilità con questa frase alternativa":	$messaggio = "se comportar como se não tivesse mais disponibilidade com esta frase alternativa"; $tr = 1; break;
case "Nota: questi dati verranno utilizzati solo in relazione<br> al servizio offerto e comunicati solo a PayPal per il<br> completamento della prenotazione":	$messaggio = "Nota: Esses dados serão utilizados apenas<br>com o serviço oferecido e comunicado<br>ao PayPal para completar a reserva"; $tr = 1; break;
case "Un codice di verifica è stato inviato a":	$messaggio = "Um código de verificação foi enviado para"; $tr = 1; break;
case "Controlla la posta e inserisci il codice in questa pagina per effettuare la prenotazione":	$messaggio = "Verifique a caixa entrada do seu e-mail e digite o código da mensagem nesta página para completar a reserva"; $tr = 1; break;
case "Codice di verifica":  		$messaggio = "Código de verificação"; $tr = 1; break;
case "Annulla":  			$messaggio = "Cancelar"; $tr = 1; break;
case "Per procedere con la prenotazione inserisci il codice o segui questo link":	$messaggio = "Para completar a sua reserva, por favor insira o código na página da reserva ou siga este atalho"; $tr = 1; break;
case "Codice verifica prenotazione":	$messaggio = "Código de verificação da reserva"; $tr = 1; break;
case "Numero eccesivo di richieste inviate dallo stesso computer":	$messaggio = "Número excessivo de pedidos enviados do mesmo dispositivo"; $tr = 1; break;
case "Completa la prenotazione pagando la caparra con PayPal":	$messaggio = "Completa sua reserva pagando o depósito com PayPal"; $tr = 1; break;
case "Quando il pagamento della caparra sarà completato riceverai una email con la conferma della prenotazione":	$messaggio = "Quando o pagamento do depósito é concluído, você receberá um e-mail com a confirmação da reserva"; $tr = 1; break;
case "Paga la caparra con PayPal":  	$messaggio = "Pagar o deposito com PayPal"; $tr = 1; break;
case "Nota: i dati della carta di credito verranno elaborati dai<br> server sicuri di PayPal ed in nessun caso comunicati a questo sito":	$messaggio = "Nota: Os dados do seu cartões de crédito serão processados por servidores seguros do PayPal. Em nenhum caso estes dodos serão revelados para náo"; $tr = 1; break;
case "Prenotazione":  			$messaggio = "Reservar"; $tr = 1; break;
case "Errore transazione PayPal":  	$messaggio = "Erro na transação PayPal"; $tr = 1; break;
case "Errore":  			$messaggio = "Erro"; $tr = 1; break;
case "Transazione inesistente o scaduta":	$messaggio = "transação inexistente ou expirada"; $tr = 1; break;
case "Codice di verifica errato":	$messaggio = "Código de verificação está errado"; $tr = 1; break;
case "Email pagante":  			$messaggio = "E-mail remetente do pagamento"; $tr = 1; break;
case "Transazione non completata, controllare la posta per conoscere lo stato della prenotazione":	$messaggio = "A transação não foi concluída. Verifique seu e-mail para saber o estado da reserva"; $tr = 1; break;
case "Grazie per la sua prenotazione":	$messaggio = "Obrigado pela sua reserva"; $tr = 1; break;
case "Dettagli della prenotazione":	$messaggio = "Detalhes da reserva"; $tr = 1; break;
case "Pagato":  			$messaggio = "Pago"; $tr = 1; break;
case "NOTA":  				$messaggio = "NOTA"; $tr = 1; break;
case "A causa della variazione di disponibilità durante il completamento della prenotazione":	$messaggio = "Devido à alteração de disponibilidade durante a realização da reserva"; $tr = 1; break;
case "il prezzo originario di":  	$messaggio = "o preço original de"; $tr = 1; break;
case "è stato variato":  		$messaggio = "foi alterado"; $tr = 1; break;
case "Contattare":  			$messaggio = "contatar"; $tr = 1; break;
case "se si desidera chiedere la cancellazione della prenotazione e un rimborso della caparra pagata":	$messaggio = "se você quiser pedir o cancelamento e reembolso do depósito pago"; $tr = 1; break;
case "Conferma prenotazione":  		$messaggio = "Confirmar a reserva"; $tr = 1; break;
case "non è stato possibile inserire la prenotazione":	$messaggio = "não foi possível introduzir a reserva"; $tr = 1; break;
case "per un rimborso della caparra pagata":	$messaggio = "por um reembolso do depósito pago"; $tr = 1; break;
case "Prenotazione fallita":  		$messaggio = "Reservas falhida"; $tr = 1; break;
case "Prenotazione inserita con successo":	$messaggio = "A reserva foi inserida com sucesso"; $tr = 1; break;
case "E' stata inviata una email di conferma della prenotazione":	$messaggio = "Uma confirmação de reserva foi enviada pelo endereço e-mail"; $tr = 1; break;
case "La prenotazione è stata inserita ma":	$messaggio = "A reserva foi inserida, mais"; $tr = 1; break;
case "il prezzo totale è variato a":	$messaggio = "o preço total mudou para"; $tr = 1; break;
case "Inserire in questa variabile l'url della pagina se \$PHP_SELF o \$SERVER_NAME non sono definiti":	$messaggio = "Inserir nesta variável a url da página se \$PHP_SELF ou \$SERVER_NAME não estão definidos"; $tr = 1; break;
case "Indirizzo email del proprio account <b style=\"font-weight: normal; text-decoration: underline;\">primario</b> di PayPal":	$messaggio = "Endereço e-mail <b style=\"font-weight: normal; text-decoration: underline;\">principal</b> da sua conta de PayPal"; $tr = 1; break;
case "si consiglia vivamente di disattivare la possibilità di ricevere pagamenti via eCheck":	$messaggio = "é altamente recomendável para desativar a capacidade de receber pagamentos via eCheck"; $tr = 1; break;
case "su questo account per evitare che la prenotazione non possa essere conclusa a causa di":	$messaggio = "nesta conta para evitar a reserva que não podem ser concluídas devido a"; $tr = 1; break;
case "variazioni di disponibilità durante l'attesa del pagamento":	$messaggio = "alterações de disponibilidade enquanto esperar para pagamento"; $tr = 1; break;
case "Valuta in cui si desidera ricevere i pagamenti PayPal":	$messaggio = "Moeda da conta PayPal"; $tr = 1; break;
case "Indirizzo email a cui mandare le comunicazioni":	$messaggio = "Endereço e-mail para enviar avisos"; $tr = 1; break;
case "Prenota con PayPal":  		$messaggio = "Reservar com PayPal"; $tr = 1; break;
case "Inviare anche comunicazioni delle mail col codice di verifica?":	$messaggio = "Enviar também as comunicações por e-mail com o código de verificação?"; $tr = 1; break;
case "verranno aggiunti al commento":	$messaggio = "serão adicionados ao comentário"; $tr = 1; break;
case "Pagina per confermare una prenotazione":  	$messaggio = "Página para confirmar reservas"; $tr = 1; break;
case "Crea la pagina per confermare una prenotazione":  	$messaggio = "Criar uma página para confirmar reservas"; $tr = 1; break;
case "Accetta modifiche solo per prenotazioni che cominciano almeno dopo":	$messaggio = "Aceitar alterações somente por reservas com início pelo menos depois"; $tr = 1; break;
case "Completa la tua prenotazione":	$messaggio = "Completa a sua reserva"; $tr = 1; break;
case "Modifica i dati":  		$messaggio = "Modificar os dados"; $tr = 1; break;
case "Codice prenotazione":  		$messaggio = "Código de reserva"; $tr = 1; break;
case "Dettagli prenotazione":  		$messaggio = "Detalhes da reserva"; $tr = 1; break;
case "I dati sono stati inseriti":	$messaggio = "Os dados foram inseridos"; $tr = 1; break;
case "Dati della carta di credito":	$messaggio = "Detalhes do cartão de crédito"; $tr = 1; break;
case "Titolare della carta":  		$messaggio = "Titular do cartão"; $tr = 1; break;
case "Tipo di carta":  			$messaggio = "Bandeira do cartão"; $tr = 1; break;
case "Numero della carta":  		$messaggio = "Número do cartão"; $tr = 1; break;
case "Data di scadenza":  		$messaggio = "Data de validade"; $tr = 1; break;
case "Numero CCV2":  			$messaggio = "Número CCV2"; $tr = 1; break;
case "Cosa è il codice di sicurezza CCV2?":	$messaggio = "O que é o código de segurança CCV2?"; $tr = 1; break;
case "Sono le ultime 3 cifre che seguono il numero della carta nel campo della firma, sul retro della carta":	$messaggio = "São os últimos 3 dígitos seguintes o número do cartão no campo de assinatura, no verso do seu cartão"; $tr = 1; break;
case "Sono le 4 cifre sopra il numero sul fronte della carta, sul lato destro o sinistro":	$messaggio = "São os 4 dígitos acima do número do cartão na frente do cartão, à direita ou esquerda"; $tr = 1; break;
case "cos'è?":  			$messaggio = "que é?"; $tr = 1; break;
case "Tipo di carta non valido":	$messaggio = "A bandeira do cartão está errada"; $tr = 1; break;
case "Numero di carta non valido":	$messaggio = "O número do cartão está errado"; $tr = 1; break;
case "Data di scadenza non valida":	$messaggio = "A data de validade está errada"; $tr = 1; break;
case "Numero CCV2 non valido":		$messaggio = "O número CCV2 está errado"; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-pt_3.0.8-1.tar.gz: pt/modt_com.php <==
<?php

switch ($messaggio) {

case "Procedere con la prenotazione":	$messaggio = "Progredir com a reserva"; $tr = 1; break;
case "altro":  				$messaggio = "outro"; $tr = 1; break;
case "Indirizzo":  			$messaggio = "Endereço"; $tr = 1; break;
case "Prenota":  			$messaggio = "Reservar"; $tr = 1; break;
case "comportati come se non vi fosse più disponibilità con questa frase alternativa":	$messaggio = "se comportar como se não tivesse mais disponibilidade com esta frase alternativa"; $tr = 1; break;
case "Nota: questi dati verranno utilizzati solo in relazione<br> al servizio offerto e comunicati solo a PayPal per il<br> completamento della prenotazione":	$messaggio = "Nota: Esses dados serão utilizados apenas<br>com o serviço oferecido e comunicado<br>ao PayPal para completar a reserva"; $tr = 1; break;
case "Un codice di verifica è stato inviato a":	$messaggio = "Um código de verificação foi enviado para"; $tr = 1; break;
case "Controlla la posta e inserisci il codice in questa pagina per effettuare la prenotazione":	$messaggio = "Verifique a caixa entrada do seu e-mail e digite o código da mensagem nesta página para completar a reserva"; $tr = 1; break;
case "Codice di verifica":  		$messaggio = "Código de verificação"; $tr = 1; break;
case "Annulla":  			$messaggio = "Cancelar"; $tr = 1; break;
case "Per procedere con la prenotazione inserisci il codice o segui questo link":	$messaggio = "Para completar a sua reserva, por favor insira o código na página da reserva ou siga este atalho"; $tr = 1; break;
case "Codice verifica prenotazione":	$messaggio = "Código de verificação da reserva"; $tr = 1; break;
case "Numero eccesivo di richieste inviate dallo stesso computer":	$messaggio = "Número excessivo de pedidos enviados do mesmo dispositivo"; $tr = 1; break;
case "Completa la prenotazione pagando la caparra con PayPal":	$messaggio = "Completa sua reserva pagando o depósito com PayPal"; $tr = 1; break;
case "Quando il pagamento della caparra sarà completato riceverai una email con la conferma della prenotazione":	$messaggio = "Quando o pagamento do depósito é concluído, você receberá um e-mail com a confirmação da reserva"; $tr = 1; break;
case "Paga la caparra con PayPal":  	$messaggio = "Pagar o deposito com PayPal"; $tr = 1; break;
case "Nota: i dati della carta di credito verranno elaborati dai<br> server sicuri di PayPal ed in nessun caso comunicati a questo sito":	$messaggio = "Nota: Os dados do seu cartões de crédito serão processados por servidores seguros do PayPal. Em nenhum caso estes dodos serão revelados para náo"; $tr = 1; break;
case "Prenotazione":  			$messaggio = "Reservar"; $tr = 1; break;
case "Errore transazione PayPal":  	$messaggio = "Erro na transação PayPal"; $tr = 1; break;
case "Errore":  			$messaggio = "Erro"; $tr = 1; break;
case "Transazione inesistente o scaduta":	$messaggio = "transação inexistente ou expirada"; $tr = 1; break;
case "Codice di verifica errato":	$messaggio = "Código de verificação está errado"; $tr = 1; break;
case "Email pagante":  			$messaggio = "E-mail remetente do pagamento"; $tr = 1; break;
case "Transazione non completata, controllare la posta per conoscere lo stato della prenotazione":	$messaggio = "A transação não foi concluída. Verifique seu e-mail para saber o estado da reserva"; $tr = 1; break;
case "Grazie per la sua prenotazione":	$messaggio = "Obrigado pela sua reserva"; $tr = 1; break;
case "Dettagli della prenotazione":	$messaggio = "Detalhes da reserva"; $tr = 1; break;
case "Pagato":  			$messaggio = "Pago"; $tr = 1; break;
case "NOTA":  				$messaggio = "NOTA"; $tr = 1; break;
case "A causa della variazione di disponibilità durante il completamento della prenotazione":	$messaggio = "Devido à alteração de disponibilidade durante a realização da reserva"; $tr = 1; break;
case "il prezzo originario di":  	$messaggio = "o preço original de"; $tr = 1; break;
case "è stato variato":  		$messaggio = "foi alterado"; $tr = 1; break;
case "Contattare":  			$messaggio = "contatar"; $tr = 1; break;
case "se si desidera chiedere la cancellazione della prenotazione e un rimborso della caparra pagata":	$messaggio = "se você quiser pedir o cancelamento e reembolso do depósito pago"; $tr = 1; break;
case "Conferma prenotazione":  		$messaggio = "Confirmar a reserva"; $tr = 1; break;
case "non è stato possibile inserire la prenotazione":	$messaggio = "não foi possível introduzir a reserva"; $tr = 1; break;
case "per un rimborso della caparra pagata":	$messaggio = "por um reembolso do depósito pago"; $tr = 1; break;
case "Prenotazione fallita":  		$messaggio = "Reservas falhida"; $tr = 1; break;
case "Prenotazione inserita con successo":	$messaggio = "A reserva foi inserida com sucesso"; $tr = 1; break;
case "E' stata inviata una email di conferma della prenotazione":	$messaggio = "Uma confirmação de reserva foi enviada pelo endereço e-mail"; $tr = 1; break;
case "La prenotazione è stata inserita ma":	$messaggio = "A reserva foi inserida, mais"; $tr = 1; break;
case "il prezzo totale è variato a":	$messaggio = "o preço total mudou para"; $tr = 1; break;
case "Inserire in questa variabile l'url della pagina se \$PHP_SELF o \$SERVER_NAME non sono definiti":	$messaggio = "Inserir nesta variável a url da página se \$PHP_SELF ou \$SERVER_NAME não estão definidos"; $tr = 1; break;
case "Indirizzo email del proprio account <b style=\"font-weight: normal; text-decoration: underline;\">primario</b> di PayPal":	$messaggio = "Endereço e-mail <b style=\"font-weight: normal; text-decoration: underline;\">principal</b> da sua conta de PayPal"; $tr = 1; break;
case "si consiglia vivamente di disattivare la possibilità di ricevere pagamenti via eCheck":	$messaggio = "é altamente recomendável para desativar a capacidade de receber pagamentos via eCheck"; $tr = 1; break;
case "su questo account per evitare che la prenotazione non possa essere conclusa a causa di":	$messaggio = "nesta conta para evitar a reserva que não podem ser concluídas devido a"; $tr = 1; break;
case "variazioni di disponibilità durante l'attesa del pagamento":	$messaggio = "alterações de disponibilidade enquanto esperar para pagamento"; $tr = 1; break;
case "Valuta in cui si desidera ricevere i pagamenti PayPal":	$messaggio = "Moeda da conta PayPal"; $tr = 1; break;
case "Indirizzo email a cui mandare le comunicazioni":	$messaggio = "Endereço e-mail para enviar avisos"; $tr = 1; break;
case "Prenota con PayPal":  		$messaggio = "Reservar com PayPal"; $tr = 1; break;
case "Inviare anche comunicazioni delle mail col codice di verifica?":	$messaggio = "Enviar também as comunicações por e-mail com o código de verificação?"; $tr = 1; break;
case "verranno aggiunti al commento":	$messaggio = "serão adicionados ao comentário"; $tr = 1; break;
case "Pagina per confermare una prenotazione":  	$messaggio = "Página para confirmar reservas"; $tr = 1; break;
case "Crea la pagina per confermare una prenotazione":  	$messaggio = "Criar uma página para confirmar reservas"; $tr = 1; break;
case "Accetta modifiche solo per prenotazioni che cominciano almeno dopo":	$messaggio = "Aceitar alterações somente por reservas com início pelo menos depois"; $tr = 1; break;
case "Completa la tua prenotazione":	$messaggio = "Completa a sua reserva"; $tr = 1; break;
case "Modifica i dati":  		$messaggio = "Modificar os dados"; $tr = 1; break;
case "Codice prenotazione":  		$messaggio = "Código de reserva"; $tr = 1; break;
case "Dettagli prenotazione":  		$messaggio = "Detalhes da reserva"; $tr = 1; break;
case "I dati sono stati inseriti":	$messaggio = "Os dados foram inseridos"; $tr = 1; break;
case "Dati della carta di credito":	$messaggio = "Detalhes do cartão de crédito"; $tr = 1; break;
case "Titolare della carta":  		$messaggio = "Titular do cartão"; $tr = 1; break;
case "Tipo di carta":  			$messaggio = "Bandeira do cartão"; $tr = 1; break;
case "Numero della carta":  		$messaggio = "N.º do cartão"; $tr = 1; break;
case "Data di scadenza":  		$messaggio = "Data de validade"; $tr = 1; break;
case "Numero CCV2":  			$messaggio = "Número CCV2"; $tr = 1; break;
case "Cosa è il codice di sicurezza CCV2?":	$messaggio = "O que é o código de segurança CCV2?"; $tr = 1; break;
case "Sono le ultime 3 cifre che seguono il numero della carta nel campo della firma, sul retro della carta":	$messaggio = "São os últimos 3 dígitos seguintes o número do cartão no campo de assinatura, no verso do seu cartão"; $tr = 1; break;
case "Sono le 4 cifre sopra il numero sul fronte della carta, sul lato destro o sinistro":	$messaggio = "São os 4 dígitos acima do número do cartão na frente do cartão, à direita ou esquerda"; $tr = 1; break;
case "cos'è?":  			$messaggio = "que é?"; $tr = 1; break;
case "Tipo di carta non valido":	$messaggio = "A bandeira do cartão está errada"; $tr = 1; break;
case "Numero di carta non valido":	$messaggio = "O n.º do cartão está errado"; $tr = 1; break;
case "Data di scadenza non valida":	$messaggio = "A data de validade está errada"; $tr = 1; break;
case "Numero CCV2 non valido":		$messaggio = "O n.º CCV2 está errado"; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;

} # fine switch ($messaggio)

?>
